==> ember-concurrency-1.0.0.tgz: package/README.md <==
# ember-concurrency

[![Build Status][build-status-img]][build-status-link]
[![NPM][npm-badge-img]][npm-badge-link]
[![Ember Observer Score][ember-observer-badge]][ember-observer-url]
![Ember Version][ember-version]

Improved concurrency primitives for Ember.js. Documentation can be
found [here](http://ember-concurrency.com).

## Installation

`ember-concurrency` is an ember-cli addon. You can install it via:

    ember install ember-concurrency

If you're using a version of `ember-concurrency` older than 0.7.5,
you'll also need to run:

    ember install ember-maybe-import-regenerator

## Documentation

The [ember-concurrency documentation site](http://ember-concurrency.com) is an ember-cli app
with interactive examples powered by ember-concurrency. It runs from
ember-concurrency's [dummy test app](https://github.com/machty/ember-concurrency/tree/master/tests/dummy/app)
(thanks to [ef4](https://github.com/ef4) for spearheading this
approach).

## Problems?

- [Open an Issue](https://github.com/machty/ember-concurrency/issues).
  - Try to replicate the issue within an [ember-twiddle][twiddle-starter]
- Ask a question in the `#e-concurrency` channel at the [Ember Community Discord server](https://discord.gg/zT3asNS)

## Contributing

See the [Contributing](CONTRIBUTING.md) guide for details.

[build-status-img]: https://travis-ci.org/machty/ember-concurrency.svg?branch=master
[build-status-link]: https://travis-ci.org/machty/ember-concurrency
[npm-badge-img]: https://badge.fury.io/js/ember-concurrency.svg
[npm-badge-link]: http://badge.fury.io/js/ember-concurrency
[ember-observer-badge]: http://emberobserver.com/badges/ember-concurrency.svg
[ember-observer-url]: http://emberobserver.com/addons/ember-concurrency
[ember-version]: https://img.shields.io/badge/Ember-2.4%2B-brightgreen.svg
[twiddle-starter]: https://ember-twiddle.com/b2b0c016f4df24261381487b60c707f3?numColumns=2&openFiles=templates.application.hbs%2Ctemplates.application.hbs

==> ember-concurrency-3.1.1.tgz: package/README.md <==
# ember-concurrency

[![Build Status][build-status-img]][build-status-link]
[![NPM][npm-badge-img]][npm-badge-link]
[![Ember Observer Score][ember-observer-badge]][ember-observer-url]
![Ember Version][ember-version]

Improved concurrency primitives for Ember.js. Documentation can be
found [here](http://ember-concurrency.com).

## Installation

`ember-concurrency` is an ember-cli addon. You can install it via:

    ember install ember-concurrency

## Documentation

The [ember-concurrency documentation site](http://ember-concurrency.com) is an ember-cli app
with interactive examples powered by ember-concurrency. It runs from
ember-concurrency's [dummy test app](https://github.com/machty/ember-concurrency/tree/master/tests/dummy/app).

## Problems?

- [Open an Issue](https://github.com/machty/ember-concurrency/issues).
  - Try to replicate the issue within an [ember-twiddle][twiddle-starter]
- Ask a question in the `#e-concurrency` channel at the [Ember Community Discord server](https://discord.gg/zT3asNS)

## Contributing

See the [Contributing](CONTRIBUTING.md) guide for details.

[build-status-img]: https://github.com/machty/ember-concurrency/workflows/CI/badge.svg
[build-status-link]: https://github.com/machty/ember-concurrency
[npm-badge-img]: https://badge.fury.io/js/ember-concurrency.svg
[npm-badge-link]: http://badge.fury.io/js/ember-concurrency
[ember-observer-badge]: http://emberobserver.com/badges/ember-concurrency.svg
[ember-observer-url]: http://emberobserver.com/addons/ember-concurrency
[ember-version]: https://img.shields.io/badge/Ember-3.8+-brightgreen.svg
[twiddle-starter]: https://ember-twiddle.com/b2b0c016f4df24261381487b60c707f3?numColumns=2&openFiles=templates.application.hbs%2Ctemplates.application.hbs
